# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/workflow/workflow_manager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.repo import repo_pb2 as prodvana_dot_repo_dot_repo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(prodvana/workflow/workflow_manager.proto\x12\x11prodvana.workflow\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$prodvana/common_config/program.proto\x1a prodvana/common_config/env.proto\x1a\x17validate/validate.proto\x1a\x18prodvana/repo/repo.proto\"\x92\x01\n\x16TrackedImageRepository\x12\x12\n\nrepository\x18\x01 \x01(\t\x12.\n\nlast_index\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x0cindex_status\x18\x03 \x01(\x0e\x32\x1e.prodvana.workflow.IndexStatus\"\x97\x01\n\rRegistryImage\x12+\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0b\n\x03tag\x18\x05 \x01(\t\x12%\n\x06\x63ommit\x18\x06 \x01(\x0b\x32\x15.prodvana.repo.CommitJ\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05R\x06\x64igestR\x04tags\"\x94\x04\n%CreateContainerRegistryIntegrationReq\x12\x39\n\x04name\x18\x06 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\t\x12-\n\x04type\x18\x04 \x01(\x0e\x32\x1f.prodvana.workflow.RegistryType\x12Z\n\x0b\x65\x63r_options\x18\x05 \x01(\x0b\x32\x43.prodvana.workflow.CreateContainerRegistryIntegrationReq.ECROptionsH\x00\x12q\n\x17public_registry_options\x18\x07 \x01(\x0b\x32N.prodvana.workflow.CreateContainerRegistryIntegrationReq.PublicRegistryOptionsH\x00\x1aV\n\nECROptions\x12\x12\n\naccess_key\x18\x01 \x01(\t\x12\x12\n\nsecret_key\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\x1a\x17\n\x15PublicRegistryOptionsB\x12\n\x10registry_options\"?\n%CreateContainerRegistryIntegrationRes\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\">\n%DeleteContainerRegistryIntegrationReq\x12\x15\n\rregistry_name\x18\x01 \x01(\t\"(\n&DeleteContainerRegistryIntegrationResp\"<\n$ListContainerRegistryIntegrationsReq\x12\x14\n\x0c\x66\x65tch_status\x18\x01 \x01(\x08\"\xcc\x02\n\x1c\x43ontainerRegistryIntegration\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x31\n\x06status\x18\x05 \x01(\x0e\x32!.prodvana.workflow.RegistryStatus\x12K\n\x08\x65\x63r_info\x18\x06 \x01(\x0b\x32\x37.prodvana.workflow.ContainerRegistryIntegration.ECRInfoH\x00\x12?\n\x0crepositories\x18\x07 \x03(\x0b\x32).prodvana.workflow.TrackedImageRepository\x1a\x19\n\x07\x45\x43RInfo\x12\x0e\n\x06region\x18\x01 \x01(\tB\x0f\n\rregistry_info\"\xe0\x03\n%ListContainerRegistryIntegrationsResp\x12w\n\x14\x63ontainer_registries\x18\x01 \x03(\x0b\x32Y.prodvana.workflow.ListContainerRegistryIntegrationsResp.ContainerRegistryIntegrationInfo\x1a\x19\n\x07\x45\x43RInfo\x12\x0e\n\x06region\x18\x01 \x01(\t\x1a\xa2\x02\n ContainerRegistryIntegrationInfo\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x31\n\x06status\x18\x06 \x01(\x0e\x32!.prodvana.workflow.RegistryStatus\x12T\n\x08\x65\x63r_info\x18\x07 \x01(\x0b\x32@.prodvana.workflow.ListContainerRegistryIntegrationsResp.ECRInfoH\x00\x42\x0f\n\rregistry_infoJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05R\x08usernameR\rmasked_secret\";\n\"GetContainerRegistryIntegrationReq\x12\x15\n\rregistry_name\x18\x01 \x01(\t\"h\n#GetContainerRegistryIntegrationResp\x12\x41\n\x08registry\x18\x01 \x01(\x0b\x32/.prodvana.workflow.ContainerRegistryIntegration\"\x95\x01\n\x1dGetContainerRegistryImagesReq\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x18\n\x10image_repository\x18\x02 \x01(\t\x12\x1b\n\x13skip_registry_cache\x18\x03 \x01(\x08\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"j\n\x1dGetContainerRegistryImagesRes\x12\x30\n\x06images\x18\x01 \x03(\x0b\x32 .prodvana.workflow.RegistryImage\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x1fListTrackedImageRepositoriesReq\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"c\n ListTrackedImageRepositoriesResp\x12?\n\x0crepositories\x18\x01 \x03(\x0b\x32).prodvana.workflow.TrackedImageRepository\"J\n\x1cGetTrackedImageRepositoryReq\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\"^\n\x1dGetTrackedImageRepositoryResp\x12=\n\nrepository\x18\x01 \x01(\x0b\x32).prodvana.workflow.TrackedImageRepository\"I\n\x19TrackImageRepositoriesReq\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x14\n\x0crepositories\x18\x02 \x03(\t\"\x1c\n\x1aTrackImageRepositoriesResp\"L\n\x1eStopTrackingImageRepositoryReq\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\"!\n\x1fStopTrackingImageRepositoryResp\"u\n\x15GetImageCommitInfoReq\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\r\n\x03tag\x18\x03 \x01(\tH\x00\x12\x0f\n\x05image\x18\x04 \x01(\tH\x00\x42\x10\n\x0eimage_id_oneof\"?\n\x16GetImageCommitInfoResp\x12%\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x15.prodvana.repo.Commit\"\x92\x01\n\x15GetProgramDefaultsReq\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\r\n\x03tag\x18\x03 \x01(\tH\x00\x12\x0f\n\x05image\x18\x04 \x01(\tH\x00\x12\x1b\n\x13skip_registry_cache\x18\x05 \x01(\x08\x42\x10\n\x0eimage_id_oneof\"\xed\x01\n\x0fProgramDefaults\x12\x0b\n\x03\x63md\x18\x01 \x03(\t\x12\x12\n\nentrypoint\x18\x02 \x03(\t\x12\x38\n\x03\x65nv\x18\x03 \x03(\x0b\x32+.prodvana.workflow.ProgramDefaults.EnvEntry\x12\x31\n\x05ports\x18\x04 \x03(\x0b\x32\".prodvana.common_config.PortConfig\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\"V\n\x16GetProgramDefaultsResp\x12<\n\x10program_defaults\x18\x01 \x01(\x0b\x32\".prodvana.workflow.ProgramDefaults\"P\n\x16GetServiceImageInfoReq\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x10\n\x08versions\x18\x02 \x03(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"\x98\x04\n\x17GetServiceImageInfoResp\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12M\n\rversion_infos\x18\x03 \x03(\x0b\x32\x36.prodvana.workflow.GetServiceImageInfoResp.VersionInfo\x1a\xc8\x01\n\x0bVersionInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12M\n\rprogram_infos\x18\x02 \x03(\x0b\x32\x36.prodvana.workflow.GetServiceImageInfoResp.ProgramInfo\x12Y\n\x13per_release_channel\x18\x03 \x03(\x0b\x32<.prodvana.workflow.GetServiceImageInfoResp.PerReleaseChannel\x1a<\n\x0bProgramInfo\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\tJ\x04\x08\x02\x10\x03R\x06\x64igest\x1a{\n\x11PerReleaseChannel\x12\x17\n\x0frelease_channel\x18\x01 \x01(\t\x12M\n\rprogram_infos\x18\x02 \x03(\x0b\x32\x36.prodvana.workflow.GetServiceImageInfoResp.ProgramInfo\"D\n\x0fInstallSlackReq\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x14\n\x0credirect_uri\x18\x03 \x01(\t\"4\n\x10InstallSlackResp\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x17\n\x15GetInstallSlackUrlReq\"%\n\x16GetInstallSlackUrlResp\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x13\n\x11UninstallSlackReq\"%\n\x12UninstallSlackResp\x12\x0f\n\x07success\x18\x01 \x01(\x08\"(\n\x0cSlackChannel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"H\n\x13InstallPagerDutyReq\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x14\n\x0credirect_uri\x18\x03 \x01(\t\"8\n\x14InstallPagerDutyResp\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x1b\n\x19GetInstallPagerDutyUrlReq\")\n\x1aGetInstallPagerDutyUrlResp\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x17\n\x15UninstallPagerDutyReq\")\n\x16UninstallPagerDutyResp\x12\x0f\n\x07success\x18\x01 \x01(\x08\",\n\x10PagerDutyService\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"E\n\x11InstallGrafanaReq\x12\x14\n\x03url\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\tapi_token\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\",\n\x12InstallGrafanaResp\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"\x15\n\x13UninstallGrafanaReq\".\n\x14UninstallGrafanaResp\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"\x1b\n\x19GetGrafanaInstallationReq\"A\n\x1aGetGrafanaInstallationResp\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x1e\n\x1cListHoneycombEnvironmentsReq\"\xba\x01\n\x1dListHoneycombEnvironmentsResp\x12[\n\x0c\x65nvironments\x18\x01 \x03(\x0b\x32\x45.prodvana.workflow.ListHoneycombEnvironmentsResp.HoneycombEnvironment\x1a<\n\x14HoneycombEnvironment\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x1a\x41\x64\x64HoneycombEnvironmentReq\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07\x61pi_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"5\n\x1b\x41\x64\x64HoneycombEnvironmentResp\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\">\n\x1dUpdateHoneycombEnvironmentReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\" \n\x1eUpdateHoneycombEnvironmentResp\"-\n\x1d\x44\x65leteHoneycombEnvironmentReq\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x1e\x44\x65leteHoneycombEnvironmentResp\"\x17\n\x15UninstallHoneycombReq\"1\n\x16UninstallHoneycombResp\x12\x17\n\x0fintegration_ids\x18\x01 \x03(\t\"\x85\x01\n\x12\x43reateGitHubAppReq\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\x03\x12\x13\n\x0bprivate_key\x18\x02 \x01(\t\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\x16\n\x0ewebhook_secret\x18\x04 \x01(\t\x12\x1b\n\x13github_organization\x18\x05 \x01(\t\"-\n\x13\x43reateGitHubAppResp\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"+\n\x10InstallGitHubReq\x12\x17\n\x0finstallation_id\x18\x01 \x01(\x03\"\x13\n\x11InstallGitHubResp\"5\n\x0bIntegration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"\x15\n\x13ListIntegrationsReq\"L\n\x14ListIntegrationsResp\x12\x34\n\x0cintegrations\x18\x01 \x03(\x0b\x32\x1e.prodvana.workflow.Integration\".\n\x14\x44\x65leteIntegrationReq\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteIntegrationResp*9\n\x0cRegistryType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0f\x44OCKER_REGISTRY\x10\x01\x12\x07\n\x03\x45\x43R\x10\x02*J\n\x0eRegistryStatus\x12\r\n\tUNDEFINED\x10\x00\x12\r\n\tCONNECTED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0e\n\nRS_PENDING\x10\x03*E\n\x0bIndexStatus\x12\x0e\n\nIS_UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08INDEXING\x10\x02\x12\x0b\n\x07INDEXED\x10\x03\x32\xcd\'\n\x0fWorkflowManager\x12}\n\x10ListIntegrations\x12&.prodvana.workflow.ListIntegrationsReq\x1a\'.prodvana.workflow.ListIntegrationsResp\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/integrations\x12\x93\x01\n\x11\x44\x65leteIntegration\x12\'.prodvana.workflow.DeleteIntegrationReq\x1a(.prodvana.workflow.DeleteIntegrationResp\"+\x82\xd3\xe4\x93\x02%*#/v1/integrations/{integration_id=*}\x12\xcf\x01\n\"CreateContainerRegistryIntegration\x12\x38.prodvana.workflow.CreateContainerRegistryIntegrationReq\x1a\x38.prodvana.workflow.CreateContainerRegistryIntegrationRes\"5\x82\xd3\xe4\x93\x02/\"*/v1/integrations/container-registry/create:\x01*\x12\xd8\x01\n\"DeleteContainerRegistryIntegration\x12\x38.prodvana.workflow.DeleteContainerRegistryIntegrationReq\x1a\x39.prodvana.workflow.DeleteContainerRegistryIntegrationResp\"=\x82\xd3\xe4\x93\x02\x37*5/v1/integrations/container-registry/{registry_name=*}\x12\xc3\x01\n!ListContainerRegistryIntegrations\x12\x37.prodvana.workflow.ListContainerRegistryIntegrationsReq\x1a\x38.prodvana.workflow.ListContainerRegistryIntegrationsResp\"+\x82\xd3\xe4\x93\x02%\x12#/v1/integrations/container-registry\x12\xcf\x01\n\x1fGetContainerRegistryIntegration\x12\x35.prodvana.workflow.GetContainerRegistryIntegrationReq\x1a\x36.prodvana.workflow.GetContainerRegistryIntegrationResp\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1/integrations/container-registry/{registry_name=*}\x12\xb1\x01\n\x13GetServiceImageInfo\x12).prodvana.workflow.GetServiceImageInfoReq\x1a*.prodvana.workflow.GetServiceImageInfoResp\"C\x82\xd3\xe4\x93\x02=\x12;/v1/applications/{application=*}/services/{service=*}/image\x12\xb4\x01\n\x1aGetContainerRegistryImages\x12\x30.prodvana.workflow.GetContainerRegistryImagesReq\x1a\x30.prodvana.workflow.GetContainerRegistryImagesRes\"2\x82\xd3\xe4\x93\x02,\x12*/v1/integrations/{integration_id=*}/images\x12\xba\x01\n\x1cListTrackedImageRepositories\x12\x32.prodvana.workflow.ListTrackedImageRepositoriesReq\x1a\x33.prodvana.workflow.ListTrackedImageRepositoriesResp\"1\x82\xd3\xe4\x93\x02+\x12)/v1/integrations/{integration_id=*}/repos\x12\xbf\x01\n\x19GetTrackedImageRepository\x12/.prodvana.workflow.GetTrackedImageRepositoryReq\x1a\x30.prodvana.workflow.GetTrackedImageRepositoryResp\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/v1/integrations/{integration_id=*}/repo/{repository=*}\x12\xb1\x01\n\x16TrackImageRepositories\x12,.prodvana.workflow.TrackImageRepositoriesReq\x1a-.prodvana.workflow.TrackImageRepositoriesResp\":\x82\xd3\xe4\x93\x02\x34\"//v1/integrations/{integration_id=*}/repos/track:\x01*\x12\xbf\x01\n\x1bStopTrackingImageRepository\x12\x31.prodvana.workflow.StopTrackingImageRepositoryReq\x1a\x32.prodvana.workflow.StopTrackingImageRepositoryResp\"9\x82\xd3\xe4\x93\x02\x33*1/v1/integrations/{integration_id=*}/repos/untrack\x12\xa7\x01\n\x12GetProgramDefaults\x12(.prodvana.workflow.GetProgramDefaultsReq\x1a).prodvana.workflow.GetProgramDefaultsResp\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/v1/integrations/{integration_id=*}/program-defaults\x12\xa8\x01\n\x12GetImageCommitInfo\x12(.prodvana.workflow.GetImageCommitInfoReq\x1a).prodvana.workflow.GetImageCommitInfoResp\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1/integrations/{integration_id=*}/image-commit-info\x12\x7f\n\x0cInstallSlack\x12\".prodvana.workflow.InstallSlackReq\x1a#.prodvana.workflow.InstallSlackResp\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/integrations/slack/install\x12\x87\x01\n\x0eUninstallSlack\x12$.prodvana.workflow.UninstallSlackReq\x1a%.prodvana.workflow.UninstallSlackResp\"(\x82\xd3\xe4\x93\x02\"* /v1/integrations/slack/uninstall\x12\x95\x01\n\x12GetInstallSlackUrl\x12(.prodvana.workflow.GetInstallSlackUrlReq\x1a).prodvana.workflow.GetInstallSlackUrlResp\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/integrations/slack/install-url\x12\x8f\x01\n\x10InstallPagerDuty\x12&.prodvana.workflow.InstallPagerDutyReq\x1a\'.prodvana.workflow.InstallPagerDutyResp\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/integrations/pagerduty/install\x12\xa5\x01\n\x16GetInstallPagerDutyUrl\x12,.prodvana.workflow.GetInstallPagerDutyUrlReq\x1a-.prodvana.workflow.GetInstallPagerDutyUrlResp\".\x82\xd3\xe4\x93\x02(\x12&/v1/integrations/pagerduty/install-url\x12\x97\x01\n\x12UninstallPagerDuty\x12(.prodvana.workflow.UninstallPagerDutyReq\x1a).prodvana.workflow.UninstallPagerDutyResp\",\x82\xd3\xe4\x93\x02&*$/v1/integrations/pagerduty/uninstall\x12\x97\x01\n\x16GetGrafanaInstallation\x12,.prodvana.workflow.GetGrafanaInstallationReq\x1a-.prodvana.workflow.GetGrafanaInstallationResp\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/integrations/grafana\x12\x8a\x01\n\x0eInstallGrafana\x12$.prodvana.workflow.InstallGrafanaReq\x1a%.prodvana.workflow.InstallGrafanaResp\"+\x82\xd3\xe4\x93\x02%\" /v1/integrations/grafana/install:\x01*\x12\x8f\x01\n\x10UninstallGrafana\x12&.prodvana.workflow.UninstallGrafanaReq\x1a\'.prodvana.workflow.UninstallGrafanaResp\"*\x82\xd3\xe4\x93\x02$*\"/v1/integrations/grafana/uninstall\x12\xae\x01\n\x19ListHoneycombEnvironments\x12/.prodvana.workflow.ListHoneycombEnvironmentsReq\x1a\x30.prodvana.workflow.ListHoneycombEnvironmentsResp\".\x82\xd3\xe4\x93\x02(\x12&/v1/integrations/honeycomb/environment\x12\xab\x01\n\x17\x41\x64\x64HoneycombEnvironment\x12-.prodvana.workflow.AddHoneycombEnvironmentReq\x1a..prodvana.workflow.AddHoneycombEnvironmentResp\"1\x82\xd3\xe4\x93\x02+\"&/v1/integrations/honeycomb/environment:\x01*\x12\xbd\x01\n\x1aUpdateHoneycombEnvironment\x12\x30.prodvana.workflow.UpdateHoneycombEnvironmentReq\x1a\x31.prodvana.workflow.UpdateHoneycombEnvironmentResp\":\x82\xd3\xe4\x93\x02\x34\x1a//v1/integrations/honeycomb/environment/{name=*}:\x01*\x12\xba\x01\n\x1a\x44\x65leteHoneycombEnvironment\x12\x30.prodvana.workflow.DeleteHoneycombEnvironmentReq\x1a\x31.prodvana.workflow.DeleteHoneycombEnvironmentResp\"7\x82\xd3\xe4\x93\x02\x31*//v1/integrations/honeycomb/environment/{name=*}\x12\x8d\x01\n\x12UninstallHoneycomb\x12(.prodvana.workflow.UninstallHoneycombReq\x1a).prodvana.workflow.UninstallHoneycombResp\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/integrations/honeycomb\x12\x88\x01\n\x0f\x43reateGitHubApp\x12%.prodvana.workflow.CreateGitHubAppReq\x1a&.prodvana.workflow.CreateGitHubAppResp\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/integrations/github/create\x12\x83\x01\n\rInstallGitHub\x12#.prodvana.workflow.InstallGitHubReq\x1a$.prodvana.workflow.InstallGitHubResp\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/integrations/github/installBMZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/workflowb\x06proto3')

_REGISTRYTYPE = DESCRIPTOR.enum_types_by_name['RegistryType']
RegistryType = enum_type_wrapper.EnumTypeWrapper(_REGISTRYTYPE)
_REGISTRYSTATUS = DESCRIPTOR.enum_types_by_name['RegistryStatus']
RegistryStatus = enum_type_wrapper.EnumTypeWrapper(_REGISTRYSTATUS)
_INDEXSTATUS = DESCRIPTOR.enum_types_by_name['IndexStatus']
IndexStatus = enum_type_wrapper.EnumTypeWrapper(_INDEXSTATUS)
UNKNOWN = 0
DOCKER_REGISTRY = 1
ECR = 2
UNDEFINED = 0
CONNECTED = 1
FAILED = 2
RS_PENDING = 3
IS_UNKNOWN = 0
PENDING = 1
INDEXING = 2
INDEXED = 3


_TRACKEDIMAGEREPOSITORY = DESCRIPTOR.message_types_by_name['TrackedImageRepository']
_REGISTRYIMAGE = DESCRIPTOR.message_types_by_name['RegistryImage']
_CREATECONTAINERREGISTRYINTEGRATIONREQ = DESCRIPTOR.message_types_by_name['CreateContainerRegistryIntegrationReq']
_CREATECONTAINERREGISTRYINTEGRATIONREQ_ECROPTIONS = _CREATECONTAINERREGISTRYINTEGRATIONREQ.nested_types_by_name['ECROptions']
_CREATECONTAINERREGISTRYINTEGRATIONREQ_PUBLICREGISTRYOPTIONS = _CREATECONTAINERREGISTRYINTEGRATIONREQ.nested_types_by_name['PublicRegistryOptions']
_CREATECONTAINERREGISTRYINTEGRATIONRES = DESCRIPTOR.message_types_by_name['CreateContainerRegistryIntegrationRes']
_DELETECONTAINERREGISTRYINTEGRATIONREQ = DESCRIPTOR.message_types_by_name['DeleteContainerRegistryIntegrationReq']
_DELETECONTAINERREGISTRYINTEGRATIONRESP = DESCRIPTOR.message_types_by_name['DeleteContainerRegistryIntegrationResp']
_LISTCONTAINERREGISTRYINTEGRATIONSREQ = DESCRIPTOR.message_types_by_name['ListContainerRegistryIntegrationsReq']
_CONTAINERREGISTRYINTEGRATION = DESCRIPTOR.message_types_by_name['ContainerRegistryIntegration']
_CONTAINERREGISTRYINTEGRATION_ECRINFO = _CONTAINERREGISTRYINTEGRATION.nested_types_by_name['ECRInfo']
_LISTCONTAINERREGISTRYINTEGRATIONSRESP = DESCRIPTOR.message_types_by_name['ListContainerRegistryIntegrationsResp']
_LISTCONTAINERREGISTRYINTEGRATIONSRESP_ECRINFO = _LISTCONTAINERREGISTRYINTEGRATIONSRESP.nested_types_by_name['ECRInfo']
_LISTCONTAINERREGISTRYINTEGRATIONSRESP_CONTAINERREGISTRYINTEGRATIONINFO = _LISTCONTAINERREGISTRYINTEGRATIONSRESP.nested_types_by_name['ContainerRegistryIntegrationInfo']
_GETCONTAINERREGISTRYINTEGRATIONREQ = DESCRIPTOR.message_types_by_name['GetContainerRegistryIntegrationReq']
_GETCONTAINERREGISTRYINTEGRATIONRESP = DESCRIPTOR.message_types_by_name['GetContainerRegistryIntegrationResp']
_GETCONTAINERREGISTRYIMAGESREQ = DESCRIPTOR.message_types_by_name['GetContainerRegistryImagesReq']
_GETCONTAINERREGISTRYIMAGESRES = DESCRIPTOR.message_types_by_name['GetContainerRegistryImagesRes']
_LISTTRACKEDIMAGEREPOSITORIESREQ = DESCRIPTOR.message_types_by_name['ListTrackedImageRepositoriesReq']
_LISTTRACKEDIMAGEREPOSITORIESRESP = DESCRIPTOR.message_types_by_name['ListTrackedImageRepositoriesResp']
_GETTRACKEDIMAGEREPOSITORYREQ = DESCRIPTOR.message_types_by_name['GetTrackedImageRepositoryReq']
_GETTRACKEDIMAGEREPOSITORYRESP = DESCRIPTOR.message_types_by_name['GetTrackedImageRepositoryResp']
_TRACKIMAGEREPOSITORIESREQ = DESCRIPTOR.message_types_by_name['TrackImageRepositoriesReq']
_TRACKIMAGEREPOSITORIESRESP = DESCRIPTOR.message_types_by_name['TrackImageRepositoriesResp']
_STOPTRACKINGIMAGEREPOSITORYREQ = DESCRIPTOR.message_types_by_name['StopTrackingImageRepositoryReq']
_STOPTRACKINGIMAGEREPOSITORYRESP = DESCRIPTOR.message_types_by_name['StopTrackingImageRepositoryResp']
_GETIMAGECOMMITINFOREQ = DESCRIPTOR.message_types_by_name['GetImageCommitInfoReq']
_GETIMAGECOMMITINFORESP = DESCRIPTOR.message_types_by_name['GetImageCommitInfoResp']
_GETPROGRAMDEFAULTSREQ = DESCRIPTOR.message_types_by_name['GetProgramDefaultsReq']
_PROGRAMDEFAULTS = DESCRIPTOR.message_types_by_name['ProgramDefaults']
_PROGRAMDEFAULTS_ENVENTRY = _PROGRAMDEFAULTS.nested_types_by_name['EnvEntry']
_GETPROGRAMDEFAULTSRESP = DESCRIPTOR.message_types_by_name['GetProgramDefaultsResp']
_GETSERVICEIMAGEINFOREQ = DESCRIPTOR.message_types_by_name['GetServiceImageInfoReq']
_GETSERVICEIMAGEINFORESP = DESCRIPTOR.message_types_by_name['GetServiceImageInfoResp']
_GETSERVICEIMAGEINFORESP_VERSIONINFO = _GETSERVICEIMAGEINFORESP.nested_types_by_name['VersionInfo']
_GETSERVICEIMAGEINFORESP_PROGRAMINFO = _GETSERVICEIMAGEINFORESP.nested_types_by_name['ProgramInfo']
_GETSERVICEIMAGEINFORESP_PERRELEASECHANNEL = _GETSERVICEIMAGEINFORESP.nested_types_by_name['PerReleaseChannel']
_INSTALLSLACKREQ = DESCRIPTOR.message_types_by_name['InstallSlackReq']
_INSTALLSLACKRESP = DESCRIPTOR.message_types_by_name['InstallSlackResp']
_GETINSTALLSLACKURLREQ = DESCRIPTOR.message_types_by_name['GetInstallSlackUrlReq']
_GETINSTALLSLACKURLRESP = DESCRIPTOR.message_types_by_name['GetInstallSlackUrlResp']
_UNINSTALLSLACKREQ = DESCRIPTOR.message_types_by_name['UninstallSlackReq']
_UNINSTALLSLACKRESP = DESCRIPTOR.message_types_by_name['UninstallSlackResp']
_SLACKCHANNEL = DESCRIPTOR.message_types_by_name['SlackChannel']
_INSTALLPAGERDUTYREQ = DESCRIPTOR.message_types_by_name['InstallPagerDutyReq']
_INSTALLPAGERDUTYRESP = DESCRIPTOR.message_types_by_name['InstallPagerDutyResp']
_GETINSTALLPAGERDUTYURLREQ = DESCRIPTOR.message_types_by_name['GetInstallPagerDutyUrlReq']
_GETINSTALLPAGERDUTYURLRESP = DESCRIPTOR.message_types_by_name['GetInstallPagerDutyUrlResp']
_UNINSTALLPAGERDUTYREQ = DESCRIPTOR.message_types_by_name['UninstallPagerDutyReq']
_UNINSTALLPAGERDUTYRESP = DESCRIPTOR.message_types_by_name['UninstallPagerDutyResp']
_PAGERDUTYSERVICE = DESCRIPTOR.message_types_by_name['PagerDutyService']
_INSTALLGRAFANAREQ = DESCRIPTOR.message_types_by_name['InstallGrafanaReq']
_INSTALLGRAFANARESP = DESCRIPTOR.message_types_by_name['InstallGrafanaResp']
_UNINSTALLGRAFANAREQ = DESCRIPTOR.message_types_by_name['UninstallGrafanaReq']
_UNINSTALLGRAFANARESP = DESCRIPTOR.message_types_by_name['UninstallGrafanaResp']
_GETGRAFANAINSTALLATIONREQ = DESCRIPTOR.message_types_by_name['GetGrafanaInstallationReq']
_GETGRAFANAINSTALLATIONRESP = DESCRIPTOR.message_types_by_name['GetGrafanaInstallationResp']
_LISTHONEYCOMBENVIRONMENTSREQ = DESCRIPTOR.message_types_by_name['ListHoneycombEnvironmentsReq']
_LISTHONEYCOMBENVIRONMENTSRESP = DESCRIPTOR.message_types_by_name['ListHoneycombEnvironmentsResp']
_LISTHONEYCOMBENVIRONMENTSRESP_HONEYCOMBENVIRONMENT = _LISTHONEYCOMBENVIRONMENTSRESP.nested_types_by_name['HoneycombEnvironment']
_ADDHONEYCOMBENVIRONMENTREQ = DESCRIPTOR.message_types_by_name['AddHoneycombEnvironmentReq']
_ADDHONEYCOMBENVIRONMENTRESP = DESCRIPTOR.message_types_by_name['AddHoneycombEnvironmentResp']
_UPDATEHONEYCOMBENVIRONMENTREQ = DESCRIPTOR.message_types_by_name['UpdateHoneycombEnvironmentReq']
_UPDATEHONEYCOMBENVIRONMENTRESP = DESCRIPTOR.message_types_by_name['UpdateHoneycombEnvironmentResp']
_DELETEHONEYCOMBENVIRONMENTREQ = DESCRIPTOR.message_types_by_name['DeleteHoneycombEnvironmentReq']
_DELETEHONEYCOMBENVIRONMENTRESP = DESCRIPTOR.message_types_by_name['DeleteHoneycombEnvironmentResp']
_UNINSTALLHONEYCOMBREQ = DESCRIPTOR.message_types_by_name['UninstallHoneycombReq']
_UNINSTALLHONEYCOMBRESP = DESCRIPTOR.message_types_by_name['UninstallHoneycombResp']
_CREATEGITHUBAPPREQ = DESCRIPTOR.message_types_by_name['CreateGitHubAppReq']
_CREATEGITHUBAPPRESP = DESCRIPTOR.message_types_by_name['CreateGitHubAppResp']
_INSTALLGITHUBREQ = DESCRIPTOR.message_types_by_name['InstallGitHubReq']
_INSTALLGITHUBRESP = DESCRIPTOR.message_types_by_name['InstallGitHubResp']
_INTEGRATION = DESCRIPTOR.message_types_by_name['Integration']
_LISTINTEGRATIONSREQ = DESCRIPTOR.message_types_by_name['ListIntegrationsReq']
_LISTINTEGRATIONSRESP = DESCRIPTOR.message_types_by_name['ListIntegrationsResp']
_DELETEINTEGRATIONREQ = DESCRIPTOR.message_types_by_name['DeleteIntegrationReq']
_DELETEINTEGRATIONRESP = DESCRIPTOR.message_types_by_name['DeleteIntegrationResp']
TrackedImageRepository = _reflection.GeneratedProtocolMessageType('TrackedImageRepository', (_message.Message,), {
  'DESCRIPTOR' : _TRACKEDIMAGEREPOSITORY,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.TrackedImageRepository)
  })
_sym_db.RegisterMessage(TrackedImageRepository)

RegistryImage = _reflection.GeneratedProtocolMessageType('RegistryImage', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYIMAGE,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.RegistryImage)
  })
_sym_db.RegisterMessage(RegistryImage)

CreateContainerRegistryIntegrationReq = _reflection.GeneratedProtocolMessageType('CreateContainerRegistryIntegrationReq', (_message.Message,), {

  'ECROptions' : _reflection.GeneratedProtocolMessageType('ECROptions', (_message.Message,), {
    'DESCRIPTOR' : _CREATECONTAINERREGISTRYINTEGRATIONREQ_ECROPTIONS,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.CreateContainerRegistryIntegrationReq.ECROptions)
    })
  ,

  'PublicRegistryOptions' : _reflection.GeneratedProtocolMessageType('PublicRegistryOptions', (_message.Message,), {
    'DESCRIPTOR' : _CREATECONTAINERREGISTRYINTEGRATIONREQ_PUBLICREGISTRYOPTIONS,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.CreateContainerRegistryIntegrationReq.PublicRegistryOptions)
    })
  ,
  'DESCRIPTOR' : _CREATECONTAINERREGISTRYINTEGRATIONREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.CreateContainerRegistryIntegrationReq)
  })
_sym_db.RegisterMessage(CreateContainerRegistryIntegrationReq)
_sym_db.RegisterMessage(CreateContainerRegistryIntegrationReq.ECROptions)
_sym_db.RegisterMessage(CreateContainerRegistryIntegrationReq.PublicRegistryOptions)

CreateContainerRegistryIntegrationRes = _reflection.GeneratedProtocolMessageType('CreateContainerRegistryIntegrationRes', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONTAINERREGISTRYINTEGRATIONRES,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.CreateContainerRegistryIntegrationRes)
  })
_sym_db.RegisterMessage(CreateContainerRegistryIntegrationRes)

DeleteContainerRegistryIntegrationReq = _reflection.GeneratedProtocolMessageType('DeleteContainerRegistryIntegrationReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONTAINERREGISTRYINTEGRATIONREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.DeleteContainerRegistryIntegrationReq)
  })
_sym_db.RegisterMessage(DeleteContainerRegistryIntegrationReq)

DeleteContainerRegistryIntegrationResp = _reflection.GeneratedProtocolMessageType('DeleteContainerRegistryIntegrationResp', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONTAINERREGISTRYINTEGRATIONRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.DeleteContainerRegistryIntegrationResp)
  })
_sym_db.RegisterMessage(DeleteContainerRegistryIntegrationResp)

ListContainerRegistryIntegrationsReq = _reflection.GeneratedProtocolMessageType('ListContainerRegistryIntegrationsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERREGISTRYINTEGRATIONSREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ListContainerRegistryIntegrationsReq)
  })
_sym_db.RegisterMessage(ListContainerRegistryIntegrationsReq)

ContainerRegistryIntegration = _reflection.GeneratedProtocolMessageType('ContainerRegistryIntegration', (_message.Message,), {

  'ECRInfo' : _reflection.GeneratedProtocolMessageType('ECRInfo', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERREGISTRYINTEGRATION_ECRINFO,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.ContainerRegistryIntegration.ECRInfo)
    })
  ,
  'DESCRIPTOR' : _CONTAINERREGISTRYINTEGRATION,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ContainerRegistryIntegration)
  })
_sym_db.RegisterMessage(ContainerRegistryIntegration)
_sym_db.RegisterMessage(ContainerRegistryIntegration.ECRInfo)

ListContainerRegistryIntegrationsResp = _reflection.GeneratedProtocolMessageType('ListContainerRegistryIntegrationsResp', (_message.Message,), {

  'ECRInfo' : _reflection.GeneratedProtocolMessageType('ECRInfo', (_message.Message,), {
    'DESCRIPTOR' : _LISTCONTAINERREGISTRYINTEGRATIONSRESP_ECRINFO,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.ListContainerRegistryIntegrationsResp.ECRInfo)
    })
  ,

  'ContainerRegistryIntegrationInfo' : _reflection.GeneratedProtocolMessageType('ContainerRegistryIntegrationInfo', (_message.Message,), {
    'DESCRIPTOR' : _LISTCONTAINERREGISTRYINTEGRATIONSRESP_CONTAINERREGISTRYINTEGRATIONINFO,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.ListContainerRegistryIntegrationsResp.ContainerRegistryIntegrationInfo)
    })
  ,
  'DESCRIPTOR' : _LISTCONTAINERREGISTRYINTEGRATIONSRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ListContainerRegistryIntegrationsResp)
  })
_sym_db.RegisterMessage(ListContainerRegistryIntegrationsResp)
_sym_db.RegisterMessage(ListContainerRegistryIntegrationsResp.ECRInfo)
_sym_db.RegisterMessage(ListContainerRegistryIntegrationsResp.ContainerRegistryIntegrationInfo)

GetContainerRegistryIntegrationReq = _reflection.GeneratedProtocolMessageType('GetContainerRegistryIntegrationReq', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERREGISTRYINTEGRATIONREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetContainerRegistryIntegrationReq)
  })
_sym_db.RegisterMessage(GetContainerRegistryIntegrationReq)

GetContainerRegistryIntegrationResp = _reflection.GeneratedProtocolMessageType('GetContainerRegistryIntegrationResp', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERREGISTRYINTEGRATIONRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetContainerRegistryIntegrationResp)
  })
_sym_db.RegisterMessage(GetContainerRegistryIntegrationResp)

GetContainerRegistryImagesReq = _reflection.GeneratedProtocolMessageType('GetContainerRegistryImagesReq', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERREGISTRYIMAGESREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetContainerRegistryImagesReq)
  })
_sym_db.RegisterMessage(GetContainerRegistryImagesReq)

GetContainerRegistryImagesRes = _reflection.GeneratedProtocolMessageType('GetContainerRegistryImagesRes', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERREGISTRYIMAGESRES,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetContainerRegistryImagesRes)
  })
_sym_db.RegisterMessage(GetContainerRegistryImagesRes)

ListTrackedImageRepositoriesReq = _reflection.GeneratedProtocolMessageType('ListTrackedImageRepositoriesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRACKEDIMAGEREPOSITORIESREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ListTrackedImageRepositoriesReq)
  })
_sym_db.RegisterMessage(ListTrackedImageRepositoriesReq)

ListTrackedImageRepositoriesResp = _reflection.GeneratedProtocolMessageType('ListTrackedImageRepositoriesResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRACKEDIMAGEREPOSITORIESRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ListTrackedImageRepositoriesResp)
  })
_sym_db.RegisterMessage(ListTrackedImageRepositoriesResp)

GetTrackedImageRepositoryReq = _reflection.GeneratedProtocolMessageType('GetTrackedImageRepositoryReq', (_message.Message,), {
  'DESCRIPTOR' : _GETTRACKEDIMAGEREPOSITORYREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetTrackedImageRepositoryReq)
  })
_sym_db.RegisterMessage(GetTrackedImageRepositoryReq)

GetTrackedImageRepositoryResp = _reflection.GeneratedProtocolMessageType('GetTrackedImageRepositoryResp', (_message.Message,), {
  'DESCRIPTOR' : _GETTRACKEDIMAGEREPOSITORYRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetTrackedImageRepositoryResp)
  })
_sym_db.RegisterMessage(GetTrackedImageRepositoryResp)

TrackImageRepositoriesReq = _reflection.GeneratedProtocolMessageType('TrackImageRepositoriesReq', (_message.Message,), {
  'DESCRIPTOR' : _TRACKIMAGEREPOSITORIESREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.TrackImageRepositoriesReq)
  })
_sym_db.RegisterMessage(TrackImageRepositoriesReq)

TrackImageRepositoriesResp = _reflection.GeneratedProtocolMessageType('TrackImageRepositoriesResp', (_message.Message,), {
  'DESCRIPTOR' : _TRACKIMAGEREPOSITORIESRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.TrackImageRepositoriesResp)
  })
_sym_db.RegisterMessage(TrackImageRepositoriesResp)

StopTrackingImageRepositoryReq = _reflection.GeneratedProtocolMessageType('StopTrackingImageRepositoryReq', (_message.Message,), {
  'DESCRIPTOR' : _STOPTRACKINGIMAGEREPOSITORYREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.StopTrackingImageRepositoryReq)
  })
_sym_db.RegisterMessage(StopTrackingImageRepositoryReq)

StopTrackingImageRepositoryResp = _reflection.GeneratedProtocolMessageType('StopTrackingImageRepositoryResp', (_message.Message,), {
  'DESCRIPTOR' : _STOPTRACKINGIMAGEREPOSITORYRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.StopTrackingImageRepositoryResp)
  })
_sym_db.RegisterMessage(StopTrackingImageRepositoryResp)

GetImageCommitInfoReq = _reflection.GeneratedProtocolMessageType('GetImageCommitInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _GETIMAGECOMMITINFOREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetImageCommitInfoReq)
  })
_sym_db.RegisterMessage(GetImageCommitInfoReq)

GetImageCommitInfoResp = _reflection.GeneratedProtocolMessageType('GetImageCommitInfoResp', (_message.Message,), {
  'DESCRIPTOR' : _GETIMAGECOMMITINFORESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetImageCommitInfoResp)
  })
_sym_db.RegisterMessage(GetImageCommitInfoResp)

GetProgramDefaultsReq = _reflection.GeneratedProtocolMessageType('GetProgramDefaultsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETPROGRAMDEFAULTSREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetProgramDefaultsReq)
  })
_sym_db.RegisterMessage(GetProgramDefaultsReq)

ProgramDefaults = _reflection.GeneratedProtocolMessageType('ProgramDefaults', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROGRAMDEFAULTS_ENVENTRY,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.ProgramDefaults.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _PROGRAMDEFAULTS,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ProgramDefaults)
  })
_sym_db.RegisterMessage(ProgramDefaults)
_sym_db.RegisterMessage(ProgramDefaults.EnvEntry)

GetProgramDefaultsResp = _reflection.GeneratedProtocolMessageType('GetProgramDefaultsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETPROGRAMDEFAULTSRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetProgramDefaultsResp)
  })
_sym_db.RegisterMessage(GetProgramDefaultsResp)

GetServiceImageInfoReq = _reflection.GeneratedProtocolMessageType('GetServiceImageInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEIMAGEINFOREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetServiceImageInfoReq)
  })
_sym_db.RegisterMessage(GetServiceImageInfoReq)

GetServiceImageInfoResp = _reflection.GeneratedProtocolMessageType('GetServiceImageInfoResp', (_message.Message,), {

  'VersionInfo' : _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), {
    'DESCRIPTOR' : _GETSERVICEIMAGEINFORESP_VERSIONINFO,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.GetServiceImageInfoResp.VersionInfo)
    })
  ,

  'ProgramInfo' : _reflection.GeneratedProtocolMessageType('ProgramInfo', (_message.Message,), {
    'DESCRIPTOR' : _GETSERVICEIMAGEINFORESP_PROGRAMINFO,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.GetServiceImageInfoResp.ProgramInfo)
    })
  ,

  'PerReleaseChannel' : _reflection.GeneratedProtocolMessageType('PerReleaseChannel', (_message.Message,), {
    'DESCRIPTOR' : _GETSERVICEIMAGEINFORESP_PERRELEASECHANNEL,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.GetServiceImageInfoResp.PerReleaseChannel)
    })
  ,
  'DESCRIPTOR' : _GETSERVICEIMAGEINFORESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetServiceImageInfoResp)
  })
_sym_db.RegisterMessage(GetServiceImageInfoResp)
_sym_db.RegisterMessage(GetServiceImageInfoResp.VersionInfo)
_sym_db.RegisterMessage(GetServiceImageInfoResp.ProgramInfo)
_sym_db.RegisterMessage(GetServiceImageInfoResp.PerReleaseChannel)

InstallSlackReq = _reflection.GeneratedProtocolMessageType('InstallSlackReq', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLSLACKREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.InstallSlackReq)
  })
_sym_db.RegisterMessage(InstallSlackReq)

InstallSlackResp = _reflection.GeneratedProtocolMessageType('InstallSlackResp', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLSLACKRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.InstallSlackResp)
  })
_sym_db.RegisterMessage(InstallSlackResp)

GetInstallSlackUrlReq = _reflection.GeneratedProtocolMessageType('GetInstallSlackUrlReq', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLSLACKURLREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetInstallSlackUrlReq)
  })
_sym_db.RegisterMessage(GetInstallSlackUrlReq)

GetInstallSlackUrlResp = _reflection.GeneratedProtocolMessageType('GetInstallSlackUrlResp', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLSLACKURLRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetInstallSlackUrlResp)
  })
_sym_db.RegisterMessage(GetInstallSlackUrlResp)

UninstallSlackReq = _reflection.GeneratedProtocolMessageType('UninstallSlackReq', (_message.Message,), {
  'DESCRIPTOR' : _UNINSTALLSLACKREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UninstallSlackReq)
  })
_sym_db.RegisterMessage(UninstallSlackReq)

UninstallSlackResp = _reflection.GeneratedProtocolMessageType('UninstallSlackResp', (_message.Message,), {
  'DESCRIPTOR' : _UNINSTALLSLACKRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UninstallSlackResp)
  })
_sym_db.RegisterMessage(UninstallSlackResp)

SlackChannel = _reflection.GeneratedProtocolMessageType('SlackChannel', (_message.Message,), {
  'DESCRIPTOR' : _SLACKCHANNEL,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.SlackChannel)
  })
_sym_db.RegisterMessage(SlackChannel)

InstallPagerDutyReq = _reflection.GeneratedProtocolMessageType('InstallPagerDutyReq', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLPAGERDUTYREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.InstallPagerDutyReq)
  })
_sym_db.RegisterMessage(InstallPagerDutyReq)

InstallPagerDutyResp = _reflection.GeneratedProtocolMessageType('InstallPagerDutyResp', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLPAGERDUTYRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.InstallPagerDutyResp)
  })
_sym_db.RegisterMessage(InstallPagerDutyResp)

GetInstallPagerDutyUrlReq = _reflection.GeneratedProtocolMessageType('GetInstallPagerDutyUrlReq', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLPAGERDUTYURLREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetInstallPagerDutyUrlReq)
  })
_sym_db.RegisterMessage(GetInstallPagerDutyUrlReq)

GetInstallPagerDutyUrlResp = _reflection.GeneratedProtocolMessageType('GetInstallPagerDutyUrlResp', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLPAGERDUTYURLRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetInstallPagerDutyUrlResp)
  })
_sym_db.RegisterMessage(GetInstallPagerDutyUrlResp)

UninstallPagerDutyReq = _reflection.GeneratedProtocolMessageType('UninstallPagerDutyReq', (_message.Message,), {
  'DESCRIPTOR' : _UNINSTALLPAGERDUTYREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UninstallPagerDutyReq)
  })
_sym_db.RegisterMessage(UninstallPagerDutyReq)

UninstallPagerDutyResp = _reflection.GeneratedProtocolMessageType('UninstallPagerDutyResp', (_message.Message,), {
  'DESCRIPTOR' : _UNINSTALLPAGERDUTYRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UninstallPagerDutyResp)
  })
_sym_db.RegisterMessage(UninstallPagerDutyResp)

PagerDutyService = _reflection.GeneratedProtocolMessageType('PagerDutyService', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYSERVICE,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.PagerDutyService)
  })
_sym_db.RegisterMessage(PagerDutyService)

InstallGrafanaReq = _reflection.GeneratedProtocolMessageType('InstallGrafanaReq', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLGRAFANAREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.InstallGrafanaReq)
  })
_sym_db.RegisterMessage(InstallGrafanaReq)

InstallGrafanaResp = _reflection.GeneratedProtocolMessageType('InstallGrafanaResp', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLGRAFANARESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.InstallGrafanaResp)
  })
_sym_db.RegisterMessage(InstallGrafanaResp)

UninstallGrafanaReq = _reflection.GeneratedProtocolMessageType('UninstallGrafanaReq', (_message.Message,), {
  'DESCRIPTOR' : _UNINSTALLGRAFANAREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UninstallGrafanaReq)
  })
_sym_db.RegisterMessage(UninstallGrafanaReq)

UninstallGrafanaResp = _reflection.GeneratedProtocolMessageType('UninstallGrafanaResp', (_message.Message,), {
  'DESCRIPTOR' : _UNINSTALLGRAFANARESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UninstallGrafanaResp)
  })
_sym_db.RegisterMessage(UninstallGrafanaResp)

GetGrafanaInstallationReq = _reflection.GeneratedProtocolMessageType('GetGrafanaInstallationReq', (_message.Message,), {
  'DESCRIPTOR' : _GETGRAFANAINSTALLATIONREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetGrafanaInstallationReq)
  })
_sym_db.RegisterMessage(GetGrafanaInstallationReq)

GetGrafanaInstallationResp = _reflection.GeneratedProtocolMessageType('GetGrafanaInstallationResp', (_message.Message,), {
  'DESCRIPTOR' : _GETGRAFANAINSTALLATIONRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.GetGrafanaInstallationResp)
  })
_sym_db.RegisterMessage(GetGrafanaInstallationResp)

ListHoneycombEnvironmentsReq = _reflection.GeneratedProtocolMessageType('ListHoneycombEnvironmentsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTHONEYCOMBENVIRONMENTSREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ListHoneycombEnvironmentsReq)
  })
_sym_db.RegisterMessage(ListHoneycombEnvironmentsReq)

ListHoneycombEnvironmentsResp = _reflection.GeneratedProtocolMessageType('ListHoneycombEnvironmentsResp', (_message.Message,), {

  'HoneycombEnvironment' : _reflection.GeneratedProtocolMessageType('HoneycombEnvironment', (_message.Message,), {
    'DESCRIPTOR' : _LISTHONEYCOMBENVIRONMENTSRESP_HONEYCOMBENVIRONMENT,
    '__module__' : 'prodvana.workflow.workflow_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.workflow.ListHoneycombEnvironmentsResp.HoneycombEnvironment)
    })
  ,
  'DESCRIPTOR' : _LISTHONEYCOMBENVIRONMENTSRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ListHoneycombEnvironmentsResp)
  })
_sym_db.RegisterMessage(ListHoneycombEnvironmentsResp)
_sym_db.RegisterMessage(ListHoneycombEnvironmentsResp.HoneycombEnvironment)

AddHoneycombEnvironmentReq = _reflection.GeneratedProtocolMessageType('AddHoneycombEnvironmentReq', (_message.Message,), {
  'DESCRIPTOR' : _ADDHONEYCOMBENVIRONMENTREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.AddHoneycombEnvironmentReq)
  })
_sym_db.RegisterMessage(AddHoneycombEnvironmentReq)

AddHoneycombEnvironmentResp = _reflection.GeneratedProtocolMessageType('AddHoneycombEnvironmentResp', (_message.Message,), {
  'DESCRIPTOR' : _ADDHONEYCOMBENVIRONMENTRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.AddHoneycombEnvironmentResp)
  })
_sym_db.RegisterMessage(AddHoneycombEnvironmentResp)

UpdateHoneycombEnvironmentReq = _reflection.GeneratedProtocolMessageType('UpdateHoneycombEnvironmentReq', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEHONEYCOMBENVIRONMENTREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UpdateHoneycombEnvironmentReq)
  })
_sym_db.RegisterMessage(UpdateHoneycombEnvironmentReq)

UpdateHoneycombEnvironmentResp = _reflection.GeneratedProtocolMessageType('UpdateHoneycombEnvironmentResp', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEHONEYCOMBENVIRONMENTRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UpdateHoneycombEnvironmentResp)
  })
_sym_db.RegisterMessage(UpdateHoneycombEnvironmentResp)

DeleteHoneycombEnvironmentReq = _reflection.GeneratedProtocolMessageType('DeleteHoneycombEnvironmentReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETEHONEYCOMBENVIRONMENTREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.DeleteHoneycombEnvironmentReq)
  })
_sym_db.RegisterMessage(DeleteHoneycombEnvironmentReq)

DeleteHoneycombEnvironmentResp = _reflection.GeneratedProtocolMessageType('DeleteHoneycombEnvironmentResp', (_message.Message,), {
  'DESCRIPTOR' : _DELETEHONEYCOMBENVIRONMENTRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.DeleteHoneycombEnvironmentResp)
  })
_sym_db.RegisterMessage(DeleteHoneycombEnvironmentResp)

UninstallHoneycombReq = _reflection.GeneratedProtocolMessageType('UninstallHoneycombReq', (_message.Message,), {
  'DESCRIPTOR' : _UNINSTALLHONEYCOMBREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UninstallHoneycombReq)
  })
_sym_db.RegisterMessage(UninstallHoneycombReq)

UninstallHoneycombResp = _reflection.GeneratedProtocolMessageType('UninstallHoneycombResp', (_message.Message,), {
  'DESCRIPTOR' : _UNINSTALLHONEYCOMBRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.UninstallHoneycombResp)
  })
_sym_db.RegisterMessage(UninstallHoneycombResp)

CreateGitHubAppReq = _reflection.GeneratedProtocolMessageType('CreateGitHubAppReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGITHUBAPPREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.CreateGitHubAppReq)
  })
_sym_db.RegisterMessage(CreateGitHubAppReq)

CreateGitHubAppResp = _reflection.GeneratedProtocolMessageType('CreateGitHubAppResp', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGITHUBAPPRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.CreateGitHubAppResp)
  })
_sym_db.RegisterMessage(CreateGitHubAppResp)

InstallGitHubReq = _reflection.GeneratedProtocolMessageType('InstallGitHubReq', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLGITHUBREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.InstallGitHubReq)
  })
_sym_db.RegisterMessage(InstallGitHubReq)

InstallGitHubResp = _reflection.GeneratedProtocolMessageType('InstallGitHubResp', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLGITHUBRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.InstallGitHubResp)
  })
_sym_db.RegisterMessage(InstallGitHubResp)

Integration = _reflection.GeneratedProtocolMessageType('Integration', (_message.Message,), {
  'DESCRIPTOR' : _INTEGRATION,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.Integration)
  })
_sym_db.RegisterMessage(Integration)

ListIntegrationsReq = _reflection.GeneratedProtocolMessageType('ListIntegrationsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTINTEGRATIONSREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ListIntegrationsReq)
  })
_sym_db.RegisterMessage(ListIntegrationsReq)

ListIntegrationsResp = _reflection.GeneratedProtocolMessageType('ListIntegrationsResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTINTEGRATIONSRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.ListIntegrationsResp)
  })
_sym_db.RegisterMessage(ListIntegrationsResp)

DeleteIntegrationReq = _reflection.GeneratedProtocolMessageType('DeleteIntegrationReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINTEGRATIONREQ,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.DeleteIntegrationReq)
  })
_sym_db.RegisterMessage(DeleteIntegrationReq)

DeleteIntegrationResp = _reflection.GeneratedProtocolMessageType('DeleteIntegrationResp', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINTEGRATIONRESP,
  '__module__' : 'prodvana.workflow.workflow_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.workflow.DeleteIntegrationResp)
  })
_sym_db.RegisterMessage(DeleteIntegrationResp)

_WORKFLOWMANAGER = DESCRIPTOR.services_by_name['WorkflowManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/workflow'
  _CREATECONTAINERREGISTRYINTEGRATIONREQ.fields_by_name['name']._options = None
  _CREATECONTAINERREGISTRYINTEGRATIONREQ.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _PROGRAMDEFAULTS_ENVENTRY._options = None
  _PROGRAMDEFAULTS_ENVENTRY._serialized_options = b'8\001'
  _INSTALLGRAFANAREQ.fields_by_name['url']._options = None
  _INSTALLGRAFANAREQ.fields_by_name['url']._serialized_options = b'\372B\004r\002\020\001'
  _INSTALLGRAFANAREQ.fields_by_name['api_token']._options = None
  _INSTALLGRAFANAREQ.fields_by_name['api_token']._serialized_options = b'\372B\004r\002\020\001'
  _ADDHONEYCOMBENVIRONMENTREQ.fields_by_name['name']._options = None
  _ADDHONEYCOMBENVIRONMENTREQ.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _ADDHONEYCOMBENVIRONMENTREQ.fields_by_name['api_key']._options = None
  _ADDHONEYCOMBENVIRONMENTREQ.fields_by_name['api_key']._serialized_options = b'\372B\004r\002\020\001'
  _WORKFLOWMANAGER.methods_by_name['ListIntegrations']._options = None
  _WORKFLOWMANAGER.methods_by_name['ListIntegrations']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/integrations'
  _WORKFLOWMANAGER.methods_by_name['DeleteIntegration']._options = None
  _WORKFLOWMANAGER.methods_by_name['DeleteIntegration']._serialized_options = b'\202\323\344\223\002%*#/v1/integrations/{integration_id=*}'
  _WORKFLOWMANAGER.methods_by_name['CreateContainerRegistryIntegration']._options = None
  _WORKFLOWMANAGER.methods_by_name['CreateContainerRegistryIntegration']._serialized_options = b'\202\323\344\223\002/\"*/v1/integrations/container-registry/create:\001*'
  _WORKFLOWMANAGER.methods_by_name['DeleteContainerRegistryIntegration']._options = None
  _WORKFLOWMANAGER.methods_by_name['DeleteContainerRegistryIntegration']._serialized_options = b'\202\323\344\223\0027*5/v1/integrations/container-registry/{registry_name=*}'
  _WORKFLOWMANAGER.methods_by_name['ListContainerRegistryIntegrations']._options = None
  _WORKFLOWMANAGER.methods_by_name['ListContainerRegistryIntegrations']._serialized_options = b'\202\323\344\223\002%\022#/v1/integrations/container-registry'
  _WORKFLOWMANAGER.methods_by_name['GetContainerRegistryIntegration']._options = None
  _WORKFLOWMANAGER.methods_by_name['GetContainerRegistryIntegration']._serialized_options = b'\202\323\344\223\0027\0225/v1/integrations/container-registry/{registry_name=*}'
  _WORKFLOWMANAGER.methods_by_name['GetServiceImageInfo']._options = None
  _WORKFLOWMANAGER.methods_by_name['GetServiceImageInfo']._serialized_options = b'\202\323\344\223\002=\022;/v1/applications/{application=*}/services/{service=*}/image'
  _WORKFLOWMANAGER.methods_by_name['GetContainerRegistryImages']._options = None
  _WORKFLOWMANAGER.methods_by_name['GetContainerRegistryImages']._serialized_options = b'\202\323\344\223\002,\022*/v1/integrations/{integration_id=*}/images'
  _WORKFLOWMANAGER.methods_by_name['ListTrackedImageRepositories']._options = None
  _WORKFLOWMANAGER.methods_by_name['ListTrackedImageRepositories']._serialized_options = b'\202\323\344\223\002+\022)/v1/integrations/{integration_id=*}/repos'
  _WORKFLOWMANAGER.methods_by_name['GetTrackedImageRepository']._options = None
  _WORKFLOWMANAGER.methods_by_name['GetTrackedImageRepository']._serialized_options = b'\202\323\344\223\0029\0227/v1/integrations/{integration_id=*}/repo/{repository=*}'
  _WORKFLOWMANAGER.methods_by_name['TrackImageRepositories']._options = None
  _WORKFLOWMANAGER.methods_by_name['TrackImageRepositories']._serialized_options = b'\202\323\344\223\0024\"//v1/integrations/{integration_id=*}/repos/track:\001*'
  _WORKFLOWMANAGER.methods_by_name['StopTrackingImageRepository']._options = None
  _WORKFLOWMANAGER.methods_by_name['StopTrackingImageRepository']._serialized_options = b'\202\323\344\223\0023*1/v1/integrations/{integration_id=*}/repos/untrack'
  _WORKFLOWMANAGER.methods_by_name['GetProgramDefaults']._options = None
  _WORKFLOWMANAGER.methods_by_name['GetProgramDefaults']._serialized_options = b'\202\323\344\223\0026\0224/v1/integrations/{integration_id=*}/program-defaults'
  _WORKFLOWMANAGER.methods_by_name['GetImageCommitInfo']._options = None
  _WORKFLOWMANAGER.methods_by_name['GetImageCommitInfo']._serialized_options = b'\202\323\344\223\0027\0225/v1/integrations/{integration_id=*}/image-commit-info'
  _WORKFLOWMANAGER.methods_by_name['InstallSlack']._options = None
  _WORKFLOWMANAGER.methods_by_name['InstallSlack']._serialized_options = b'\202\323\344\223\002 \022\036/v1/integrations/slack/install'
  _WORKFLOWMANAGER.methods_by_name['UninstallSlack']._options = None
  _WORKFLOWMANAGER.methods_by_name['UninstallSlack']._serialized_options = b'\202\323\344\223\002\"* /v1/integrations/slack/uninstall'
  _WORKFLOWMANAGER.methods_by_name['GetInstallSlackUrl']._options = None
  _WORKFLOWMANAGER.methods_by_name['GetInstallSlackUrl']._serialized_options = b'\202\323\344\223\002$\022\"/v1/integrations/slack/install-url'
  _WORKFLOWMANAGER.methods_by_name['InstallPagerDuty']._options = None
  _WORKFLOWMANAGER.methods_by_name['InstallPagerDuty']._serialized_options = b'\202\323\344\223\002$\022\"/v1/integrations/pagerduty/install'
  _WORKFLOWMANAGER.methods_by_name['GetInstallPagerDutyUrl']._options = None
  _WORKFLOWMANAGER.methods_by_name['GetInstallPagerDutyUrl']._serialized_options = b'\202\323\344\223\002(\022&/v1/integrations/pagerduty/install-url'
  _WORKFLOWMANAGER.methods_by_name['UninstallPagerDuty']._options = None
  _WORKFLOWMANAGER.methods_by_name['UninstallPagerDuty']._serialized_options = b'\202\323\344\223\002&*$/v1/integrations/pagerduty/uninstall'
  _WORKFLOWMANAGER.methods_by_name['GetGrafanaInstallation']._options = None
  _WORKFLOWMANAGER.methods_by_name['GetGrafanaInstallation']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/integrations/grafana'
  _WORKFLOWMANAGER.methods_by_name['InstallGrafana']._options = None
  _WORKFLOWMANAGER.methods_by_name['InstallGrafana']._serialized_options = b'\202\323\344\223\002%\" /v1/integrations/grafana/install:\001*'
  _WORKFLOWMANAGER.methods_by_name['UninstallGrafana']._options = None
  _WORKFLOWMANAGER.methods_by_name['UninstallGrafana']._serialized_options = b'\202\323\344\223\002$*\"/v1/integrations/grafana/uninstall'
  _WORKFLOWMANAGER.methods_by_name['ListHoneycombEnvironments']._options = None
  _WORKFLOWMANAGER.methods_by_name['ListHoneycombEnvironments']._serialized_options = b'\202\323\344\223\002(\022&/v1/integrations/honeycomb/environment'
  _WORKFLOWMANAGER.methods_by_name['AddHoneycombEnvironment']._options = None
  _WORKFLOWMANAGER.methods_by_name['AddHoneycombEnvironment']._serialized_options = b'\202\323\344\223\002+\"&/v1/integrations/honeycomb/environment:\001*'
  _WORKFLOWMANAGER.methods_by_name['UpdateHoneycombEnvironment']._options = None
  _WORKFLOWMANAGER.methods_by_name['UpdateHoneycombEnvironment']._serialized_options = b'\202\323\344\223\0024\032//v1/integrations/honeycomb/environment/{name=*}:\001*'
  _WORKFLOWMANAGER.methods_by_name['DeleteHoneycombEnvironment']._options = None
  _WORKFLOWMANAGER.methods_by_name['DeleteHoneycombEnvironment']._serialized_options = b'\202\323\344\223\0021*//v1/integrations/honeycomb/environment/{name=*}'
  _WORKFLOWMANAGER.methods_by_name['UninstallHoneycomb']._options = None
  _WORKFLOWMANAGER.methods_by_name['UninstallHoneycomb']._serialized_options = b'\202\323\344\223\002\034*\032/v1/integrations/honeycomb'
  _WORKFLOWMANAGER.methods_by_name['CreateGitHubApp']._options = None
  _WORKFLOWMANAGER.methods_by_name['CreateGitHubApp']._serialized_options = b'\202\323\344\223\002 \022\036/v1/integrations/github/create'
  _WORKFLOWMANAGER.methods_by_name['InstallGitHub']._options = None
  _WORKFLOWMANAGER.methods_by_name['InstallGitHub']._serialized_options = b'\202\323\344\223\002!\022\037/v1/integrations/github/install'
  _REGISTRYTYPE._serialized_start=6377
  _REGISTRYTYPE._serialized_end=6434
  _REGISTRYSTATUS._serialized_start=6436
  _REGISTRYSTATUS._serialized_end=6510
  _INDEXSTATUS._serialized_start=6512
  _INDEXSTATUS._serialized_end=6581
  _TRACKEDIMAGEREPOSITORY._serialized_start=250
  _TRACKEDIMAGEREPOSITORY._serialized_end=396
  _REGISTRYIMAGE._serialized_start=399
  _REGISTRYIMAGE._serialized_end=550
  _CREATECONTAINERREGISTRYINTEGRATIONREQ._serialized_start=553
  _CREATECONTAINERREGISTRYINTEGRATIONREQ._serialized_end=1085
  _CREATECONTAINERREGISTRYINTEGRATIONREQ_ECROPTIONS._serialized_start=954
  _CREATECONTAINERREGISTRYINTEGRATIONREQ_ECROPTIONS._serialized_end=1040
  _CREATECONTAINERREGISTRYINTEGRATIONREQ_PUBLICREGISTRYOPTIONS._serialized_start=1042
  _CREATECONTAINERREGISTRYINTEGRATIONREQ_PUBLICREGISTRYOPTIONS._serialized_end=1065
  _CREATECONTAINERREGISTRYINTEGRATIONRES._serialized_start=1087
  _CREATECONTAINERREGISTRYINTEGRATIONRES._serialized_end=1150
  _DELETECONTAINERREGISTRYINTEGRATIONREQ._serialized_start=1152
  _DELETECONTAINERREGISTRYINTEGRATIONREQ._serialized_end=1214
  _DELETECONTAINERREGISTRYINTEGRATIONRESP._serialized_start=1216
  _DELETECONTAINERREGISTRYINTEGRATIONRESP._serialized_end=1256
  _LISTCONTAINERREGISTRYINTEGRATIONSREQ._serialized_start=1258
  _LISTCONTAINERREGISTRYINTEGRATIONSREQ._serialized_end=1318
  _CONTAINERREGISTRYINTEGRATION._serialized_start=1321
  _CONTAINERREGISTRYINTEGRATION._serialized_end=1653
  _CONTAINERREGISTRYINTEGRATION_ECRINFO._serialized_start=1611
  _CONTAINERREGISTRYINTEGRATION_ECRINFO._serialized_end=1636
  _LISTCONTAINERREGISTRYINTEGRATIONSRESP._serialized_start=1656
  _LISTCONTAINERREGISTRYINTEGRATIONSRESP._serialized_end=2136
  _LISTCONTAINERREGISTRYINTEGRATIONSRESP_ECRINFO._serialized_start=1611
  _LISTCONTAINERREGISTRYINTEGRATIONSRESP_ECRINFO._serialized_end=1636
  _LISTCONTAINERREGISTRYINTEGRATIONSRESP_CONTAINERREGISTRYINTEGRATIONINFO._serialized_start=1846
  _LISTCONTAINERREGISTRYINTEGRATIONSRESP_CONTAINERREGISTRYINTEGRATIONINFO._serialized_end=2136
  _GETCONTAINERREGISTRYINTEGRATIONREQ._serialized_start=2138
  _GETCONTAINERREGISTRYINTEGRATIONREQ._serialized_end=2197
  _GETCONTAINERREGISTRYINTEGRATIONRESP._serialized_start=2199
  _GETCONTAINERREGISTRYINTEGRATIONRESP._serialized_end=2303
  _GETCONTAINERREGISTRYIMAGESREQ._serialized_start=2306
  _GETCONTAINERREGISTRYIMAGESREQ._serialized_end=2455
  _GETCONTAINERREGISTRYIMAGESRES._serialized_start=2457
  _GETCONTAINERREGISTRYIMAGESRES._serialized_end=2563
  _LISTTRACKEDIMAGEREPOSITORIESREQ._serialized_start=2565
  _LISTTRACKEDIMAGEREPOSITORIESREQ._serialized_end=2622
  _LISTTRACKEDIMAGEREPOSITORIESRESP._serialized_start=2624
  _LISTTRACKEDIMAGEREPOSITORIESRESP._serialized_end=2723
  _GETTRACKEDIMAGEREPOSITORYREQ._serialized_start=2725
  _GETTRACKEDIMAGEREPOSITORYREQ._serialized_end=2799
  _GETTRACKEDIMAGEREPOSITORYRESP._serialized_start=2801
  _GETTRACKEDIMAGEREPOSITORYRESP._serialized_end=2895
  _TRACKIMAGEREPOSITORIESREQ._serialized_start=2897
  _TRACKIMAGEREPOSITORIESREQ._serialized_end=2970
  _TRACKIMAGEREPOSITORIESRESP._serialized_start=2972
  _TRACKIMAGEREPOSITORIESRESP._serialized_end=3000
  _STOPTRACKINGIMAGEREPOSITORYREQ._serialized_start=3002
  _STOPTRACKINGIMAGEREPOSITORYREQ._serialized_end=3078
  _STOPTRACKINGIMAGEREPOSITORYRESP._serialized_start=3080
  _STOPTRACKINGIMAGEREPOSITORYRESP._serialized_end=3113
  _GETIMAGECOMMITINFOREQ._serialized_start=3115
  _GETIMAGECOMMITINFOREQ._serialized_end=3232
  _GETIMAGECOMMITINFORESP._serialized_start=3234
  _GETIMAGECOMMITINFORESP._serialized_end=3297
  _GETPROGRAMDEFAULTSREQ._serialized_start=3300
  _GETPROGRAMDEFAULTSREQ._serialized_end=3446
  _PROGRAMDEFAULTS._serialized_start=3449
  _PROGRAMDEFAULTS._serialized_end=3686
  _PROGRAMDEFAULTS_ENVENTRY._serialized_start=3610
  _PROGRAMDEFAULTS_ENVENTRY._serialized_end=3686
  _GETPROGRAMDEFAULTSRESP._serialized_start=3688
  _GETPROGRAMDEFAULTSRESP._serialized_end=3774
  _GETSERVICEIMAGEINFOREQ._serialized_start=3776
  _GETSERVICEIMAGEINFOREQ._serialized_end=3856
  _GETSERVICEIMAGEINFORESP._serialized_start=3859
  _GETSERVICEIMAGEINFORESP._serialized_end=4395
  _GETSERVICEIMAGEINFORESP_VERSIONINFO._serialized_start=4008
  _GETSERVICEIMAGEINFORESP_VERSIONINFO._serialized_end=4208
  _GETSERVICEIMAGEINFORESP_PROGRAMINFO._serialized_start=4210
  _GETSERVICEIMAGEINFORESP_PROGRAMINFO._serialized_end=4270
  _GETSERVICEIMAGEINFORESP_PERRELEASECHANNEL._serialized_start=4272
  _GETSERVICEIMAGEINFORESP_PERRELEASECHANNEL._serialized_end=4395
  _INSTALLSLACKREQ._serialized_start=4397
  _INSTALLSLACKREQ._serialized_end=4465
  _INSTALLSLACKRESP._serialized_start=4467
  _INSTALLSLACKRESP._serialized_end=4519
  _GETINSTALLSLACKURLREQ._serialized_start=4521
  _GETINSTALLSLACKURLREQ._serialized_end=4544
  _GETINSTALLSLACKURLRESP._serialized_start=4546
  _GETINSTALLSLACKURLRESP._serialized_end=4583
  _UNINSTALLSLACKREQ._serialized_start=4585
  _UNINSTALLSLACKREQ._serialized_end=4604
  _UNINSTALLSLACKRESP._serialized_start=4606
  _UNINSTALLSLACKRESP._serialized_end=4643
  _SLACKCHANNEL._serialized_start=4645
  _SLACKCHANNEL._serialized_end=4685
  _INSTALLPAGERDUTYREQ._serialized_start=4687
  _INSTALLPAGERDUTYREQ._serialized_end=4759
  _INSTALLPAGERDUTYRESP._serialized_start=4761
  _INSTALLPAGERDUTYRESP._serialized_end=4817
  _GETINSTALLPAGERDUTYURLREQ._serialized_start=4819
  _GETINSTALLPAGERDUTYURLREQ._serialized_end=4846
  _GETINSTALLPAGERDUTYURLRESP._serialized_start=4848
  _GETINSTALLPAGERDUTYURLRESP._serialized_end=4889
  _UNINSTALLPAGERDUTYREQ._serialized_start=4891
  _UNINSTALLPAGERDUTYREQ._serialized_end=4914
  _UNINSTALLPAGERDUTYRESP._serialized_start=4916
  _UNINSTALLPAGERDUTYRESP._serialized_end=4957
  _PAGERDUTYSERVICE._serialized_start=4959
  _PAGERDUTYSERVICE._serialized_end=5003
  _INSTALLGRAFANAREQ._serialized_start=5005
  _INSTALLGRAFANAREQ._serialized_end=5074
  _INSTALLGRAFANARESP._serialized_start=5076
  _INSTALLGRAFANARESP._serialized_end=5120
  _UNINSTALLGRAFANAREQ._serialized_start=5122
  _UNINSTALLGRAFANAREQ._serialized_end=5143
  _UNINSTALLGRAFANARESP._serialized_start=5145
  _UNINSTALLGRAFANARESP._serialized_end=5191
  _GETGRAFANAINSTALLATIONREQ._serialized_start=5193
  _GETGRAFANAINSTALLATIONREQ._serialized_end=5220
  _GETGRAFANAINSTALLATIONRESP._serialized_start=5222
  _GETGRAFANAINSTALLATIONRESP._serialized_end=5287
  _LISTHONEYCOMBENVIRONMENTSREQ._serialized_start=5289
  _LISTHONEYCOMBENVIRONMENTSREQ._serialized_end=5319
  _LISTHONEYCOMBENVIRONMENTSRESP._serialized_start=5322
  _LISTHONEYCOMBENVIRONMENTSRESP._serialized_end=5508
  _LISTHONEYCOMBENVIRONMENTSRESP_HONEYCOMBENVIRONMENT._serialized_start=5448
  _LISTHONEYCOMBENVIRONMENTSRESP_HONEYCOMBENVIRONMENT._serialized_end=5508
  _ADDHONEYCOMBENVIRONMENTREQ._serialized_start=5510
  _ADDHONEYCOMBENVIRONMENTREQ._serialized_end=5587
  _ADDHONEYCOMBENVIRONMENTRESP._serialized_start=5589
  _ADDHONEYCOMBENVIRONMENTRESP._serialized_end=5642
  _UPDATEHONEYCOMBENVIRONMENTREQ._serialized_start=5644
  _UPDATEHONEYCOMBENVIRONMENTREQ._serialized_end=5706
  _UPDATEHONEYCOMBENVIRONMENTRESP._serialized_start=5708
  _UPDATEHONEYCOMBENVIRONMENTRESP._serialized_end=5740
  _DELETEHONEYCOMBENVIRONMENTREQ._serialized_start=5742
  _DELETEHONEYCOMBENVIRONMENTREQ._serialized_end=5787
  _DELETEHONEYCOMBENVIRONMENTRESP._serialized_start=5789
  _DELETEHONEYCOMBENVIRONMENTRESP._serialized_end=5821
  _UNINSTALLHONEYCOMBREQ._serialized_start=5823
  _UNINSTALLHONEYCOMBREQ._serialized_end=5846
  _UNINSTALLHONEYCOMBRESP._serialized_start=5848
  _UNINSTALLHONEYCOMBRESP._serialized_end=5897
  _CREATEGITHUBAPPREQ._serialized_start=5900
  _CREATEGITHUBAPPREQ._serialized_end=6033
  _CREATEGITHUBAPPRESP._serialized_start=6035
  _CREATEGITHUBAPPRESP._serialized_end=6080
  _INSTALLGITHUBREQ._serialized_start=6082
  _INSTALLGITHUBREQ._serialized_end=6125
  _INSTALLGITHUBRESP._serialized_start=6127
  _INSTALLGITHUBRESP._serialized_end=6146
  _INTEGRATION._serialized_start=6148
  _INTEGRATION._serialized_end=6201
  _LISTINTEGRATIONSREQ._serialized_start=6203
  _LISTINTEGRATIONSREQ._serialized_end=6224
  _LISTINTEGRATIONSRESP._serialized_start=6226
  _LISTINTEGRATIONSRESP._serialized_end=6302
  _DELETEINTEGRATIONREQ._serialized_start=6304
  _DELETEINTEGRATIONREQ._serialized_end=6350
  _DELETEINTEGRATIONRESP._serialized_start=6352
  _DELETEINTEGRATIONRESP._serialized_end=6375
  _WORKFLOWMANAGER._serialized_start=6584
  _WORKFLOWMANAGER._serialized_end=11653
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/settings/organization/users.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.users import users_pb2 as prodvana_dot_users_dot_users__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*prodvana/settings/organization/users.proto\x12\x1eprodvana.settings.organization\x1a\x1cgoogle/api/annotations.proto\x1a\x1aprodvana/users/users.proto\"A\n\x0cSettingsUser\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.prodvana.users.User\x12\r\n\x05roles\x18\x02 \x03(\t\"\x1d\n\nGetUserReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"I\n\x0bGetUserResp\x12:\n\x04user\x18\x01 \x01(\x0b\x32,.prodvana.settings.organization.SettingsUser\"\x0e\n\x0cListRolesReq\"3\n\x0eRoleDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"N\n\rListRolesResp\x12=\n\x05roles\x18\x01 \x03(\x0b\x32..prodvana.settings.organization.RoleDefinition\"5\n\x0cListUsersReq\x12\x12\n\npage_token\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\"e\n\rListUsersResp\x12;\n\x05users\x18\x01 \x03(\x0b\x32,.prodvana.settings.organization.SettingsUser\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"-\n\x0bSetRolesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\"\x0e\n\x0cSetRolesResp2\xf7\x04\n\x14UsersSettingsManager\x12\x95\x01\n\x07GetUser\x12*.prodvana.settings.organization.GetUserReq\x1a+.prodvana.settings.organization.GetUserResp\"1\x82\xd3\xe4\x93\x02+\x12)/v1/settings/organization/users/{user_id}\x12\x91\x01\n\tListUsers\x12,.prodvana.settings.organization.ListUsersReq\x1a-.prodvana.settings.organization.ListUsersResp\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/settings/organization/users\x12\x91\x01\n\tListRoles\x12,.prodvana.settings.organization.ListRolesReq\x1a-.prodvana.settings.organization.ListRolesResp\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/settings/organization/roles\x12\x9e\x01\n\x08SetRoles\x12+.prodvana.settings.organization.SetRolesReq\x1a,.prodvana.settings.organization.SetRolesResp\"7\x82\xd3\xe4\x93\x02\x31\"//v1/settings/organization/users/{user_id}/rolesBZZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/settings/organizationb\x06proto3')



_SETTINGSUSER = DESCRIPTOR.message_types_by_name['SettingsUser']
_GETUSERREQ = DESCRIPTOR.message_types_by_name['GetUserReq']
_GETUSERRESP = DESCRIPTOR.message_types_by_name['GetUserResp']
_LISTROLESREQ = DESCRIPTOR.message_types_by_name['ListRolesReq']
_ROLEDEFINITION = DESCRIPTOR.message_types_by_name['RoleDefinition']
_LISTROLESRESP = DESCRIPTOR.message_types_by_name['ListRolesResp']
_LISTUSERSREQ = DESCRIPTOR.message_types_by_name['ListUsersReq']
_LISTUSERSRESP = DESCRIPTOR.message_types_by_name['ListUsersResp']
_SETROLESREQ = DESCRIPTOR.message_types_by_name['SetRolesReq']
_SETROLESRESP = DESCRIPTOR.message_types_by_name['SetRolesResp']
SettingsUser = _reflection.GeneratedProtocolMessageType('SettingsUser', (_message.Message,), {
  'DESCRIPTOR' : _SETTINGSUSER,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.SettingsUser)
  })
_sym_db.RegisterMessage(SettingsUser)

GetUserReq = _reflection.GeneratedProtocolMessageType('GetUserReq', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERREQ,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.GetUserReq)
  })
_sym_db.RegisterMessage(GetUserReq)

GetUserResp = _reflection.GeneratedProtocolMessageType('GetUserResp', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERRESP,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.GetUserResp)
  })
_sym_db.RegisterMessage(GetUserResp)

ListRolesReq = _reflection.GeneratedProtocolMessageType('ListRolesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESREQ,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.ListRolesReq)
  })
_sym_db.RegisterMessage(ListRolesReq)

RoleDefinition = _reflection.GeneratedProtocolMessageType('RoleDefinition', (_message.Message,), {
  'DESCRIPTOR' : _ROLEDEFINITION,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.RoleDefinition)
  })
_sym_db.RegisterMessage(RoleDefinition)

ListRolesResp = _reflection.GeneratedProtocolMessageType('ListRolesResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESRESP,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.ListRolesResp)
  })
_sym_db.RegisterMessage(ListRolesResp)

ListUsersReq = _reflection.GeneratedProtocolMessageType('ListUsersReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSREQ,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.ListUsersReq)
  })
_sym_db.RegisterMessage(ListUsersReq)

ListUsersResp = _reflection.GeneratedProtocolMessageType('ListUsersResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSRESP,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.ListUsersResp)
  })
_sym_db.RegisterMessage(ListUsersResp)

SetRolesReq = _reflection.GeneratedProtocolMessageType('SetRolesReq', (_message.Message,), {
  'DESCRIPTOR' : _SETROLESREQ,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.SetRolesReq)
  })
_sym_db.RegisterMessage(SetRolesReq)

SetRolesResp = _reflection.GeneratedProtocolMessageType('SetRolesResp', (_message.Message,), {
  'DESCRIPTOR' : _SETROLESRESP,
  '__module__' : 'prodvana.settings.organization.users_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.settings.organization.SetRolesResp)
  })
_sym_db.RegisterMessage(SetRolesResp)

_USERSSETTINGSMANAGER = DESCRIPTOR.services_by_name['UsersSettingsManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/settings/organization'
  _USERSSETTINGSMANAGER.methods_by_name['GetUser']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['GetUser']._serialized_options = b'\202\323\344\223\002+\022)/v1/settings/organization/users/{user_id}'
  _USERSSETTINGSMANAGER.methods_by_name['ListUsers']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['ListUsers']._serialized_options = b'\202\323\344\223\002!\022\037/v1/settings/organization/users'
  _USERSSETTINGSMANAGER.methods_by_name['ListRoles']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['ListRoles']._serialized_options = b'\202\323\344\223\002!\022\037/v1/settings/organization/roles'
  _USERSSETTINGSMANAGER.methods_by_name['SetRoles']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['SetRoles']._serialized_options = b'\202\323\344\223\0021\"//v1/settings/organization/users/{user_id}/roles'
  _SETTINGSUSER._serialized_start=136
  _SETTINGSUSER._serialized_end=201
  _GETUSERREQ._serialized_start=203
  _GETUSERREQ._serialized_end=232
  _GETUSERRESP._serialized_start=234
  _GETUSERRESP._serialized_end=307
  _LISTROLESREQ._serialized_start=309
  _LISTROLESREQ._serialized_end=323
  _ROLEDEFINITION._serialized_start=325
  _ROLEDEFINITION._serialized_end=376
  _LISTROLESRESP._serialized_start=378
  _LISTROLESRESP._serialized_end=456
  _LISTUSERSREQ._serialized_start=458
  _LISTUSERSREQ._serialized_end=511
  _LISTUSERSRESP._serialized_start=513
  _LISTUSERSRESP._serialized_end=614
  _SETROLESREQ._serialized_start=616
  _SETROLESREQ._serialized_end=661
  _SETROLESRESP._serialized_start=663
  _SETROLESRESP._serialized_end=677
  _USERSSETTINGSMANAGER._serialized_start=680
  _USERSSETTINGSMANAGER._serialized_end=1311
# @@protoc_insertion_point(module_scope)
